<?php

namespace Drupal\hanging_conjunctions_filter;

/**
 * Provides text modification methods.
 */
class TextReplacement {

  /**
   * List of terms that should not be at the end of the line.
   *
   * @var array
   *   Terms specific for Polish typography.
   */
  protected $terms = [
    '—',
    '[a-z]',
    'aby',
    'al.',
    'albo',
    'ale',
    'ależ',
    'ani',
    'aż',
    'b.',
    'bez',
    'bł.',
    'bo',
    'br.',
    'by',
    'bym',
    'byś',
    'co',
    'cyt.',
    'cz.',
    'czy',
    'czyt.',
    'dla',
    'dn.',
    'do',
    'doc.',
    'dr',
    'ds.',
    'dyr.',
    'dz.',
    'fot.',
    'gdy',
    'gdyby',
    'gdybym',
    'gdybyś',
    'gdyż',
    'godz.',
    'im.',
    'inż.',
    'iż',
    'jak',
    'jw.',
    'kol.',
    'komu',
    'ks.',
    'która',
    'którego',
    'której',
    'któremu',
    'który',
    'których',
    'którym',
    'którzy',
    'lecz',
    'lic.',
    'lub',
    'm.in.',
    'max',
    'mgr',
    'min',
    'moich',
    'moje',
    'mojego',
    'mojej',
    'mojemu',
    'mój',
    'mych',
    'na',
    'nad',
    'nie',
    'niech',
    'np.',
    'nr',
    'nr.',
    'nt.',
    'nw.',
    'od',
    'oraz',
    'os.',
    'p.',
    'pl.',
    'pn.',
    'po',
    'pod',
    'pot.',
    'prof.',
    'przed',
    'przez',
    'pt.',
    'pw.',
    'pw.',
    'śp.',
    'św.',
    'tak',
    'tamtej',
    'tamto',
    'te',
    'tej',
    'tel.',
    'tj.',
    'to',
    'twoich',
    'twoje',
    'twojego',
    'twojej',
    'twój',
    'twych',
    'tylko',
    'ul.',
    'we',
    'wg',
    'więc',
    'woj.',
    'za',
    'ze',
    'że',
    'żeby',
    'żebyś',
  ];

  /**
   * Adds non breaking space after conjunction and specific words.
   *
   * @param string $text
   *   The source text.
   * @param string $langcode
   *   The langcode of the source text.
   *
   * @return string
   *   The output text with non breaking space after special words.
   */
  public function processHangingConjunctions($text, $langcode) {
    if (mb_strlen($text) < 20 || $langcode != 'pl') {
      return $text;
    }

    foreach ($this->terms as $term) {
      $text = preg_replace('/\s(' . $term . ')(\s)/i', ' $1&nbsp;', $text);
      $text = preg_replace('/\s(' . $term . '),(\s)/i', ' $1,&nbsp;', $text);
      $text = preg_replace('/\s(' . $term . ')(\s)-\s/i', ' $1&nbsp;-&nbsp;', $text);
    }

    return $text;
  }

}
