<?php

namespace Drupal\Tests\hanging_conjunctions_filter\Unit;

use Drupal\Tests\UnitTestCase;
use Drupal\hanging_conjunctions_filter\TextReplacement;

/**
 * @coversDefaultClass \Drupal\hanging_conjunctions_filter\TextReplacement
 * @group hanging_conjunctions_filter
 */
class TextReplacementTest extends UnitTestCase {

  /**
   * Tests adding non breaking space after conjunction.
   *
   * @param string $text
   *   The source text.
   * @param string $expected
   *   The expected text.
   * @param string|null $langcode
   *   The langcode of the source text.
   *
   * @dataProvider providerHangingConjunctions
   */
  public function testProcessHangingConjunctions($text, $expected, $langcode = NULL) {
    $replacement = new TextReplacement();
    $this->assertEquals($expected, $replacement->processHangingConjunctions($text, $langcode));
  }

  /**
   * Provides data for self::testProcessHangingConjunctions().
   *
   * @return array
   *   An array of test data.
   */
  public function providerHangingConjunctions() {
    return [
      [
        'Panu Zagłobie odwaga uderzyła niespodzianie do głowy jak wino. Być może, że to desperacja dała mu taki do czynu pochop; być może nadzieja, że pan Wołodyjowski jeszcze blisko, dość, że gołą szablą błysnął, oczyma zatoczył straszliwie i zakrzyknął:',
        'Panu Zagłobie odwaga uderzyła niespodzianie do&nbsp;głowy jak&nbsp;wino. Być może, że&nbsp;to&nbsp;desperacja dała mu taki do&nbsp;czynu pochop; być może nadzieja, że&nbsp;pan Wołodyjowski jeszcze blisko, dość, że&nbsp;gołą szablą błysnął, oczyma zatoczył straszliwie i&nbsp;zakrzyknął:',
        'pl',
      ],
      // Do not add a non breaking space at the beginning of the text.
      [
        'I pracował dalej, starając się jak najciszej uderzać i tylko wówczas, gdy rozmowa mołojców głuszyła lekkie uderzenia.',
        'I pracował dalej, starając się jak&nbsp;najciszej uderzać i&nbsp;tylko wówczas, gdy&nbsp;rozmowa mołojców głuszyła lekkie uderzenia.',
        'pl',
      ],
      // Ignore case sensitive.
      [
        'ROK 1647 BYŁ TO DZIWNY ROK, W KTÓRYM ROZMAITE ZNAKI NA NIEBIE I ZIEMI ZWIASTOWAŁY JAKOWEŚ KLĘSKI I NADZWYCZAJNE ZDARZENIA.',
        'ROK 1647 BYŁ TO&nbsp;DZIWNY ROK, W&nbsp;KTÓRYM ROZMAITE ZNAKI NA&nbsp;NIEBIE I&nbsp;ZIEMI ZWIASTOWAŁY JAKOWEŚ KLĘSKI I&nbsp;NADZWYCZAJNE ZDARZENIA.',
        'pl',
      ],
    ];
  }

}
